@@ -555,7 +555,7 @@ procman_save_config (ProcData *data)
 	procman_save_tree_state (data->client, data->tree, "/apps/procman/proctree");
 	procman_save_tree_state (data->client, data->disk_list, "/apps/procman/disktreenew");
 		
-	gdk_drawable_get_size (data->app->window, &width, &height);
+	gdk_drawable_get_size (gtk_widget_get_window (data->app), &width, &height);
 	data->config.width = width;
 	data->config.height = height;
 	
